@@ -450,8 +450,8 @@ parse_error (guint status,
     return;
   case SOUP_STATUS_CANT_RESOLVE_PROXY:
   case SOUP_STATUS_CANT_CONNECT_PROXY:
-    g_simple_async_result_set_error (result, GRL_NET_WC_ERROR,
-                                     GRL_NET_WC_ERROR_PROXY_ERROR,
+    g_simple_async_result_set_error (result, G_IO_ERROR,
+                                     G_IO_ERROR_PROXY_FAILED,
                                      _("Cannot connect to the proxy server"));
     return;
   case SOUP_STATUS_INTERNAL_SERVER_ERROR: /* 500 */
@@ -482,8 +482,8 @@ parse_error (guint status,
                                      response);
     return;
   case SOUP_STATUS_CANCELLED:
-    g_simple_async_result_set_error (result, GRL_NET_WC_ERROR,
-                                     GRL_NET_WC_ERROR_CANCELLED,
+    g_simple_async_result_set_error (result, G_IO_ERROR,
+                                     G_IO_ERROR_CANCELLED,
                                      _("Operation was cancelled"));
     return;
   default:
@@ -590,13 +590,13 @@ read_async_cb (GObject *source,
   g_object_unref (source);
 
   if (error) {
-    if (error->code == G_IO_ERROR_CANCELLED) {
-      g_simple_async_result_set_error (result, GRL_NET_WC_ERROR,
-                                       GRL_NET_WC_ERROR_CANCELLED,
+    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      g_simple_async_result_set_error (result, G_IO_ERROR,
+                                       G_IO_ERROR_CANCELLED,
                                        _("Operation was cancelled"));
     } else {
-      g_simple_async_result_set_error (result, GRL_NET_WC_ERROR,
-                                       GRL_NET_WC_ERROR_UNAVAILABLE,
+      g_simple_async_result_set_error (result, G_IO_ERROR,
+                                       G_IO_ERROR_FAILED,
                                        _("Data not available"));
     }
 
@@ -636,9 +636,13 @@ reply_cb (GObject *source,
   GInputStream *in = soup_request_send_finish (rr->request, res, &error);
 
   if (error) {
-    g_simple_async_result_set_error (result, GRL_NET_WC_ERROR,
-                                     GRL_NET_WC_ERROR_UNAVAILABLE,
-                                     _("Data not available"));
+    if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+      g_simple_async_result_set_from_error (result, error);
+    } else {
+      g_simple_async_result_set_error (result, G_IO_ERROR,
+                                       G_IO_ERROR_FAILED,
+                                       _("Data not available"));
+    }
     g_error_free (error);
 
     g_simple_async_result_complete (result);
@@ -686,8 +690,8 @@ get_url_now (GrlNetWc *self,
 
   if (!rr->request) {
     g_simple_async_result_set_error (G_SIMPLE_ASYNC_RESULT (result),
-                                     GRL_NET_WC_ERROR,
-                                     GRL_NET_WC_ERROR_UNAVAILABLE,
+                                     G_IO_ERROR,
+                                     G_IO_ERROR_INVALID_ARGUMENT,
                                      _("Invalid URL %s"),
                                      url);
     g_simple_async_result_complete (G_SIMPLE_ASYNC_RESULT (result));
