@@ -1744,6 +1744,41 @@ grl_media_set_album (GrlMedia *media, const gchar *album)
                        album);
 }
 
+/**
+ * grl_media_set_album_artist:
+ * @media: the media instance
+ * @album: the audio's album main artist
+ *
+ * Set the main artist of the album of the media
+ *
+ * Since: 0.3.1
+ */
+void
+grl_media_set_album_artist (GrlMedia *media, const gchar *album_artist)
+{
+  g_return_if_fail (GRL_IS_MEDIA (media));
+  grl_data_set_string (GRL_DATA (media), GRL_METADATA_KEY_ALBUM_ARTIST,
+                       album_artist);
+}
+
+/**
+ * grl_media_set_album_disc_number:
+ * @media: the media instance
+ * @disc_number: the disc number within an album
+ *
+ * Set the disc number of the media for multi-disc album sets.
+ *
+ * Since: 0.3.1
+ */
+void
+grl_media_set_album_disc_number (GrlMedia *media, gint disc_number)
+{
+  g_return_if_fail (GRL_IS_MEDIA (media));
+  grl_data_set_int (GRL_DATA (media),
+                    GRL_METADATA_KEY_ALBUM_DISC_NUMBER,
+                    disc_number);
+}
+
 /**
  * grl_media_set_artist:
  * @media: the media instance
@@ -1761,6 +1796,23 @@ grl_media_set_artist (GrlMedia *media, const gchar *artist)
                        artist);
 }
 
+/**
+ * grl_media_set_composer:
+ * @media: the media instance
+ * @artist: the audio's composer
+ *
+ * Set the composer of the media
+ *
+ * Since: 0.3.1
+ */
+void
+grl_media_set_composer (GrlMedia *media, const gchar *composer)
+{
+  g_return_if_fail (GRL_IS_MEDIA (media));
+  grl_data_set_string (GRL_DATA (media), GRL_METADATA_KEY_COMPOSER,
+                       composer);
+}
+
 /**
  * grl_media_set_width:
  * @media: the media instance
@@ -3119,6 +3171,36 @@ grl_media_get_album (GrlMedia *media)
   return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_ALBUM);
 }
 
+/**
+ * grl_media_get_album_artist:
+ * @media: the media instance
+ *
+ * Returns: the main artist of the album of the media
+ *
+ * Since: 0.3.1
+ */
+const gchar *
+grl_media_get_album_artist (GrlMedia *media)
+{
+  g_return_val_if_fail (GRL_MEDIA (media), NULL);
+  return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_ALBUM_ARTIST);
+}
+
+/**
+ * grl_media_get_album_disc_number:
+ * @media: the media instance
+ *
+ * Returns: the disc number of the media for multi-disc album sets.
+ *
+ * Since: 0.3.1
+ */
+gint
+grl_media_get_album_disc_number (GrlMedia *media)
+{
+  g_return_val_if_fail (GRL_MEDIA (media), 0);
+  return grl_data_get_int (GRL_DATA (media), GRL_METADATA_KEY_ALBUM_DISC_NUMBER);
+}
+
 /**
  * grl_media_get_artist:
  * @media: the media instance
@@ -3162,6 +3244,49 @@ grl_media_get_artist_nth (GrlMedia *media, guint index)
   }
 }
 
+/**
+ * grl_media_get_composer:
+ * @media: the media instance
+ *
+ * Returns: the composer of the media
+ *
+ * Since: 0.3.1
+ */
+const gchar *
+grl_media_get_composer (GrlMedia *media)
+{
+  g_return_val_if_fail (GRL_MEDIA (media), NULL);
+  return grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_COMPOSER);
+}
+
+/**
+ * grl_media_get_composer_nth:
+ * @media: the media instance
+ * @index: element to retrieve, starting at 0
+ *
+ * Returns: the n-th composer of the media
+ *
+ * Since: 0.3.1
+ */
+const gchar *
+grl_media_get_composer_nth (GrlMedia *media, guint index)
+{
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
+    grl_data_get_related_keys (GRL_DATA (media),
+                               GRL_METADATA_KEY_COMPOSER,
+                               index);
+
+  if (!relkeys) {
+    return NULL;
+  } else {
+    return grl_related_keys_get_string (relkeys, GRL_METADATA_KEY_COMPOSER);
+  }
+}
+
 /**
  * grl_media_get_media_type:
  * @media: the media instance
