@@ -70,6 +70,10 @@ GRL_LOG_DOMAIN_STATIC(test_ui_log_domain);
 
 #define THETVDB_KEY "3F476CEF2FBD0FB0"
 
+/* ----- AcoustID key ---- */
+
+#define ACOUSTID_KEY "4ihkDsH37X"
+
 /* ----- Other ----- */
 
 #define BROWSE_FLAGS (GRL_RESOLVE_FAST_ONLY | GRL_RESOLVE_IDLE_RELAY)
@@ -1783,6 +1787,19 @@ set_thetvdb_config (void)
   grl_registry_add_config (registry, config, NULL);
 }
 
+static void
+set_acoustid_config (void)
+{
+  GrlConfig *config;
+  GrlRegistry *registry;
+
+  config = grl_config_new ("grl-acoustid", NULL);
+  grl_config_set_api_key (config, ACOUSTID_KEY);
+
+  registry = grl_registry_get_default ();
+  grl_registry_add_config (registry, config, NULL);
+}
+
 static void
 set_local_config (void)
 {
@@ -2379,6 +2396,7 @@ configure_plugins (void)
   set_vimeo_config ();
   set_tmdb_config ();
   set_thetvdb_config ();
+  set_acoustid_config ();
   set_local_config ();
   set_filesystem_config ();
 }
